!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
!!! Program for creation of a NetCDF file containing the Radiation   !!!
!!!           data (SOBS and THBS, obtained from COSMO Meteograms)   !!!
!!!           and dumping these two variable as a function of time   !!!
!!! This code is customized for the data of 1-December-2017          !!!
!!! Last Updated: DBS (March 01, 2022)                               !!!
!!! Compilation Syntax:                                              !!!
!!! 	gfortran -I/usr/include -L/usr/lib64 -lnetcdf -lnetcdff -o program.x program.f90
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

	Program add_radiation_parameter

	USE netcdf
	implicit none

!	Character(len=100), Parameter ::FILE_NAME ="nesting-01Dec2017-00-e.nc"
	Character(len=100), Parameter::FILE_NAME="nesting-01Dec2017-479-30m.nc"
    
	Integer, Parameter	:: itime_rad=25

	Real, Dimension(itime_rad) :: time_rad, rad_sw_in, rad_lw_in
	Real, Dimension(itime_rad) :: rad_sw_in1, rad_lw_in1
	Real, Dimension(itime_rad) :: rad_sw_in2, rad_lw_in2

	Integer	:: ncid, varid, time_raddimid, rad_sw_indimid, rad_lw_indimid
	Integer :: ichoice, i

	Character(len=*),Parameter :: TIME_RAD_NAME="time_rad"
	Character(len=*),Parameter :: RAD_SW_IN_NAME= "rad_sw_in"
	Character(len=*),Parameter :: RAD_LW_IN_NAME= "rad_lw_in"

	Character (len = *), parameter :: UNITS = "units"
  	Character (len = *), parameter :: TIME_RAD_UNITS = "seconds"
  	Character (len = *), parameter :: RAD_SW_IN_UNITS = "W m-2"
  	Character (len = *), parameter :: RAD_LW_IN_UNITS = "W m-2"

	Character (len = *), parameter :: LNAME = "long_name"
	Character (len = *), parameter :: SNAME = "standard_name"
  	Character (len = *), parameter :: TIME_RAD_LNAME = "time"
  	Character (len = *), parameter :: RAD_SW_IN_SNAME = "sobs"
  	Character (len = *), parameter :: RAD_LW_IN_SNAME = "thbs"

  	Character (len = *), parameter :: RAD_SW_IN_LOD = "1"
  	Character (len = *), parameter :: RAD_LW_IN_LOD = "1"

	Real, Parameter :: fillval_rad_sw_in = -9999.9
	Real, Parameter :: fillval_rad_lw_in = -9999.9

	Integer :: time_rad_varid, rad_sw_in_varid, rad_lw_in_varid
	Integer :: time_rad_dimid, rad_sw_in_dimid, rad_lw_in_dimid

	Integer, Parameter :: lod_rad = 1

	Data time_rad /    0.0,  3600.0,  7200.0, 10800.0, 14400.0,     &
                       18000.0, 21600.0, 25200.0, 28800.0, 32400.0,     &
                       36000.0, 39600.0, 43200.0, 46800.0, 50400.0,     &
                       54000.0, 57600.0, 61200.0, 64800.0, 68400.0,     &
                       72000.0, 75600.0, 79200.0, 82800.0, 86400.0/

	Data rad_sw_in /  0.00,     0.10,    25.50,    78.30,    78.00, &
                        142.50,   154.30,   329.30,   235.30,   190.20, &
                         88.60,    28.70,    11.00,     0.70,     0.00, &
                          0.00,     0.00,     0.00,     0.00,     0.00, &
                          0.00,     0.00,     0.00,     0.00,     0.00/

	Data rad_lw_in / 430.40,  425.70,  428.00,  427.60,  433.00,    &
                         432.50,  432.00,  426.90,  429.70,  424.30,    &
                         423.10,  425.50,  426.80,  427.00,  428.70,    &
                         425.30,  423.70,  425.20,  420.80,  418.40,    &
                         424.70,  425.50,  425.10,  422.60,  426.70/

	Call check( nf90_open(FILE_NAME, nf90_write, ncid) )

	Call check( nf90_redef(ncid) )
  
	Call check( nf90_def_dim(ncid, TIME_RAD_NAME, itime_rad, time_rad_dimid) )

	Call check( nf90_def_var(ncid, TIME_RAD_NAME, NF90_REAL, time_rad_dimid, time_rad_varid) )
	Call check( nf90_def_var(ncid, RAD_SW_IN_NAME, NF90_REAL, time_rad_dimid, rad_sw_in_varid) )
	Call check( nf90_def_var(ncid, RAD_LW_IN_NAME, NF90_REAL, time_rad_dimid, rad_lw_in_varid) )

	Call check( nf90_put_att(ncid, time_rad_varid, UNITS, TIME_RAD_UNITS) )
	Call check( nf90_put_att(ncid, rad_sw_in_varid, UNITS, RAD_SW_IN_UNITS) )
	Call check( nf90_put_att(ncid, rad_lw_in_varid, UNITS, RAD_LW_IN_UNITS) )

	Call check( nf90_put_att(ncid, time_rad_varid, LNAME, TIME_RAD_LNAME) )
	Call check( nf90_put_att(ncid, rad_sw_in_varid, SNAME, RAD_SW_IN_SNAME) )
	Call check( nf90_put_att(ncid, rad_lw_in_varid, SNAME, RAD_LW_IN_SNAME) )

	Call check( nf90_put_att(ncid, rad_sw_in_varid, "_FillValue", fillval_rad_sw_in) )
	Call check( nf90_put_att(ncid, rad_lw_in_varid, "_FillValue", fillval_rad_lw_in) )

	Call check( nf90_put_att(ncid, rad_sw_in_varid, "lod", lod_rad) )
	Call check( nf90_put_att(ncid, rad_lw_in_varid, "lod", lod_rad) )

	Call check ( nf90_enddef(ncid) )

	Call check ( nf90_put_var(ncid, time_rad_varid, time_rad) )
	Call check ( nf90_put_var(ncid, rad_sw_in_varid, rad_sw_in) )
	Call check ( nf90_put_var(ncid, rad_lw_in_varid, rad_lw_in) )

	Call check ( nf90_close(ncid) )

	Print *, '01-Dec-2017 Dynamic Driver is updated with radiation data !'

contains
   	Subroutine check(status)
        integer, intent ( in) :: status
        if(status /= nf90_noerr) then
         print *, trim(nf90_strerror(status))
         stop "Stopped"
        end if
   	End subroutine check

	End program add_radiation_parameter 
