!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
!!! Program for creation of a NetCDF file containing the Radiation   !!!
!!!           data (SOBS and THBS, obtained from COSMO Meteograms)   !!!
!!!           and dumping these two variable as a function of time   !!!
!!! This code is customized for the data of 1-December-2017          !!!
!!! Last Updated: DBS (March 01, 2022)                               !!!
!!! Compilation Syntax:                                              !!!
!!! 	gfortran -I/usr/include -L/usr/lib64 -lnetcdf -lnetcdff -o program.x program.f90
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

	Program add_radiation_parameter

	USE netcdf
	implicit none

	Character(len=100), Parameter ::  FILE_NAME ="nesting-01Dec2017-00.nc"
    
	Integer, Parameter	:: itime_rad=25

	Real, Dimension(itime_rad) :: time_rad, rad_sw_in, rad_lw_in
	Real, Dimension(itime_rad) :: rad_sw_in1, rad_lw_in1
	Real, Dimension(itime_rad) :: rad_sw_in2, rad_lw_in2

	Integer	:: ncid, varid, time_raddimid, rad_sw_indimid, rad_lw_indimid
	Integer :: ichoice, i

	Character(len=*),Parameter :: TIME_RAD_NAME="time_rad"
	Character(len=*),Parameter :: RAD_SW_IN_NAME= "rad_sw_in"
	Character(len=*),Parameter :: RAD_LW_IN_NAME= "rad_lw_in"

	Character (len = *), parameter :: UNITS = "units"
  	Character (len = *), parameter :: TIME_RAD_UNITS = "seconds"
  	Character (len = *), parameter :: RAD_SW_IN_UNITS = "W m-2"
  	Character (len = *), parameter :: RAD_LW_IN_UNITS = "W m-2"

	Character (len = *), parameter :: LNAME = "long_name"
	Character (len = *), parameter :: SNAME = "standard_name"
  	Character (len = *), parameter :: TIME_RAD_LNAME = "time"
  	Character (len = *), parameter :: RAD_SW_IN_SNAME = "sobs"
  	Character (len = *), parameter :: RAD_LW_IN_SNAME = "thbs"

  	Character (len = *), parameter :: RAD_SW_IN_LOD = "1"
  	Character (len = *), parameter :: RAD_LW_IN_LOD = "1"

	Real, Parameter :: fillval_rad_sw_in = -9999.9
	Real, Parameter :: fillval_rad_lw_in = -9999.9

	Integer :: time_rad_varid, rad_sw_in_varid, rad_lw_in_varid
	Integer :: time_rad_dimid, rad_sw_in_dimid, rad_lw_in_dimid

	Integer, Parameter :: lod_rad = 1

	Data time_rad /    0.0,  3600.0,  7200.0, 10800.0, 14400.0,     &
                       18000.0, 21600.0, 25200.0, 28800.0, 32400.0,     &
                       36000.0, 39600.0, 43200.0, 46800.0, 50400.0,     &
                       54000.0, 57600.0, 61200.0, 64800.0, 68400.0,     &
                       72000.0, 75600.0, 79200.0, 82800.0, 86400.0/

!########################################################################
!## Bottom set is SOBS and THBS data 
!########################################################################
!	Data rad_sw_in1/  0.000,   1.238,  53.411, 167.530, 280.220,    & 
!                        201.731,  32.576, 119.458, 381.052,  53.909,    &
!                        100.378,  31.617,   6.485,   0.000,   0.000,    &
!                          0.000,   0.000,   0.000,   0.000,   0.000,    &
!                          0.000,   0.000,   0.000,   0.000,   0.000/
!
!	Data rad_lw_in1/ 10.976,   8.337,  13.322,  22.936,  32.622,    &
!                         32.675,  26.956,  16.615,  33.552,  30.965,    &
!                         23.504,  21.203,  18.733,  16.575,  15.722,    &
!                         18.344,  19.718,  19.203,  19.982,  19.412,    &
!                         22.512,  17.958,  17.514,  17.459,  12.195/
!########################################################################

!########################################################################
!## Bottom set is SOBT and THBT data 
!########################################################################
	Data rad_sw_in /    0.0,     8.0,   131.5,   324.8,   493.6,    &
                          488.7,   349.1,   450.8,   668.6,   290.4,    &
                          252.9,   116.0,    34.5,     0.0,     0.0,    &
                            0.0,     0.0,     0.0,     0.0,     0.0,    &
                            0.0,     0.0,     0.0,     0.0,     0.0/

	Data rad_lw_in /  216.5,   210.6,   189.0,   160.2,   189.7,    &
                          135.4,   137.1,   227.8,   227.3,   129.0,    &
                          105.4,   114.9,   101.3,   122.2,   186.1,    &
                          152.5,   139.7,   208.5,   183.4,   200.4,    &
                          229.9,   171.7,   146.4,   133.3,   135.8/
!########################################################################

!	Write (*, 11)
! 11	Format (20(/), 5x, 'WOULD YOU LIKE TO USE SOBS AND THBS DATA?', &
!        /,  5x, 'IF YES, PLEASE ENTER "1".', /, 5x,                     &
!        'IF YOU PREFER TO USE SOBT AND THBT DATA, PLEASE ENTER "0".', /,&
!        5x, 'NOW ENTER YOUR CHOICE (EITHER 1 OR O)', 3(/),              &
!        5x, '1 ---> USE SOBS AND THBS DATA', /,                         &
!        5x, '0 ---> USE SOBT AND THBT DATA', 3(/))
!
!	Read (*, *) ichoice 
!
!	Do i = 1, itime_rad
!	If (ichoice.eq.1) rad_sw_in(i) = rad_sw_in1(i)
!	If (ichoice.eq.1) rad_lw_in(i) = rad_lw_in1(i)
!	If (ichoice.eq.2) rad_sw_in(i) = rad_sw_in2(i)
!	If (ichoice.eq.2) rad_lw_in(i) = rad_lw_in2(i)
!	Enddo

	Call check( nf90_open(FILE_NAME, nf90_write, ncid) )

	Call check( nf90_redef(ncid) )
  
	Call check( nf90_def_dim(ncid, TIME_RAD_NAME, itime_rad, time_rad_dimid) )

	Call check( nf90_def_var(ncid, TIME_RAD_NAME, NF90_REAL, time_rad_dimid, time_rad_varid) )
	Call check( nf90_def_var(ncid, RAD_SW_IN_NAME, NF90_REAL, time_rad_dimid, rad_sw_in_varid) )
	Call check( nf90_def_var(ncid, RAD_LW_IN_NAME, NF90_REAL, time_rad_dimid, rad_lw_in_varid) )

	Call check( nf90_put_att(ncid, time_rad_varid, UNITS, TIME_RAD_UNITS) )
	Call check( nf90_put_att(ncid, rad_sw_in_varid, UNITS, RAD_SW_IN_UNITS) )
	Call check( nf90_put_att(ncid, rad_lw_in_varid, UNITS, RAD_LW_IN_UNITS) )

	Call check( nf90_put_att(ncid, time_rad_varid, LNAME, TIME_RAD_LNAME) )
	Call check( nf90_put_att(ncid, rad_sw_in_varid, SNAME, RAD_SW_IN_SNAME) )
	Call check( nf90_put_att(ncid, rad_lw_in_varid, SNAME, RAD_LW_IN_SNAME) )

	Call check( nf90_put_att(ncid, rad_sw_in_varid, "_FillValue", fillval_rad_sw_in) )
	Call check( nf90_put_att(ncid, rad_lw_in_varid, "_FillValue", fillval_rad_lw_in) )

	Call check( nf90_put_att(ncid, rad_sw_in_varid, "lod", lod_rad) )
	Call check( nf90_put_att(ncid, rad_lw_in_varid, "lod", lod_rad) )

	Call check ( nf90_enddef(ncid) )

	Call check ( nf90_put_var(ncid, time_rad_varid, time_rad) )
	Call check ( nf90_put_var(ncid, rad_sw_in_varid, rad_sw_in) )
	Call check ( nf90_put_var(ncid, rad_lw_in_varid, rad_lw_in) )

	Call check ( nf90_close(ncid) )

	Print *, '01-Dec-2017 Dynamic Driver is updated with radiation data !'

contains
   	Subroutine check(status)
        integer, intent ( in) :: status
        if(status /= nf90_noerr) then
         print *, trim(nf90_strerror(status))
         stop "Stopped"
        end if
   	End subroutine check

	End program add_radiation_parameter 
