!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
!!! Program for creation of a NetCDF file containing the Radiation   !!!
!!!           data (SOBS and THBS, obtained from COSMO Meteograms)   !!!
!!!           and dumping these two variable as a function of time   !!!
!!! This code is customized for the data of 5-December-2017          !!!
!!! Last Updated: DBS (March 01, 2022)                               !!!
!!! Compilation Syntax:                                              !!!
!!! 	gfortran -I/usr/include -L/usr/lib64 -lnetcdf -lnetcdff -o program.x program.f90
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

	Program add_radiation_parameter

	USE netcdf
	implicit none

	Character(len=100), Parameter :: FILE_NAME ="nesting-05Dec2017-00.nc"
    
	Integer, Parameter	:: itime_rad=25

	Real, Dimension(itime_rad) :: time_rad, rad_sw_in, rad_lw_in
	Real, Dimension(itime_rad) :: rad_sw_in1, rad_lw_in1
	Real, Dimension(itime_rad) :: rad_sw_in2, rad_lw_in2

	Integer	:: ncid, varid, time_raddimid, rad_sw_indimid, rad_lw_indimid
	Integer :: ichoice, i

	Character(len=*),Parameter :: TIME_RAD_NAME="time_rad"
	Character(len=*),Parameter :: RAD_SW_IN_NAME= "rad_sw_in"
	Character(len=*),Parameter :: RAD_LW_IN_NAME= "rad_lw_in"

	Character (len = *), parameter :: UNITS = "units"
  	Character (len = *), parameter :: TIME_RAD_UNITS = "seconds"
  	Character (len = *), parameter :: RAD_SW_IN_UNITS = "W m-2"
  	Character (len = *), parameter :: RAD_LW_IN_UNITS = "W m-2"

	Character (len = *), parameter :: LNAME = "long_name"
	Character (len = *), parameter :: SNAME = "standard_name"
  	Character (len = *), parameter :: TIME_RAD_LNAME = "time"
  	Character (len = *), parameter :: RAD_SW_IN_SNAME = "sobs"
  	Character (len = *), parameter :: RAD_LW_IN_SNAME = "thbs"

  	Character (len = *), parameter :: RAD_SW_IN_LOD = "1"
  	Character (len = *), parameter :: RAD_LW_IN_LOD = "1"

	Real, Parameter :: fillval_rad_sw_in = -9999.9
	Real, Parameter :: fillval_rad_lw_in = -9999.9

	Integer :: time_rad_varid, rad_sw_in_varid, rad_lw_in_varid
	Integer :: time_rad_dimid, rad_sw_in_dimid, rad_lw_in_dimid

	Integer, Parameter :: lod_rad = 1

	Data time_rad /    0.0,  3600.0,  7200.0, 10800.0, 14400.0,     &
                       18000.0, 21600.0, 25200.0, 28800.0, 32400.0,     &
                       36000.0, 39600.0, 43200.0, 46800.0, 50400.0,     &
                       54000.0, 57600.0, 61200.0, 64800.0, 68400.0,     &
                       72000.0, 75600.0, 79200.0, 82800.0, 86400.0/

!########################################################################
! Bottom Data is SOBS and THBS 
!########################################################################
!	Data rad_sw_in1/ 0.000,   5.761, 165.521, 368.043, 533.863,     &
!                       651.671, 648.470, 702.786, 714.590, 580.978,     &
!                       394.386, 183.453,  37.115,   0.000,   0.000,     &
!                         0.000,   0.000,   0.000,   0.000,   0.000,     &
!                         0.000,   0.000,   0.000,   0.000,   0.000/
!
!	Data rad_lw_in1/60.688,  57.512,  69.186,  86.558,  97.304,     &
!                       105.194,  85.555,  91.839, 107.446, 104.856,     &
!                        98.374,  89.545,  69.129,  49.532,  34.361,     &
!                        29.206,  23.422,  19.056,  25.989,  25.823,     &
!                        24.540,   9.845,  16.781,  16.133,  22.230/
!########################################################################

!########################################################################
! Bottom Data is SOBT and THBT 
!########################################################################
	Data rad_sw_in /   0.0,    12.1,   257.5,   519.8,   731.7,     &
                         882.7,   909.5,   965.4,   960.0,   806.8,     &
                         586.7,   326.8,    93.4,     0.0,     0.0,     &
                           0.0,     0.0,     0.0,     0.0,     0.0,     &
                           0.0,     0.0,     0.0,     0.0,     0.0/

	Data rad_lw_in / 285.4,   285.5,   289.6,   293.9,   295.7,     &
                         297.8,   289.4,   294.8,   299.3,   299.7,     &
                         298.0,   293.9,   287.7,   168.9,   131.2,     &
                         110.5,   100.9,   104.0,   132.2,   222.7,     &
                         251.6,   209.1,   202.2,   139.8,   140.8/
!########################################################################

!	Write (*, 11)
! 11	Format (20(/), 5x, 'WOULD YOU LIKE TO USE SOBS AND THBS DATA?', &
!        /,  5x, 'IF YES, PLEASE ENTER "1".', /, 5x,                     &
!        'IF YOU PREFER TO USE SOBT AND THBT DATA, PLEASE ENTER "0".', /,&
!        5x, 'NOW ENTER YOUR CHOICE (EITHER 1 OR O)', 3(/),              &
!        5x, '1 ---> USE SOBS AND THBS DATA', /,                         &
!        5x, '0 ---> USE SOBT AND THBT DATA', 3(/))
!
!	Read (*, *) ichoice 
!
!	Do i = 1, itime_rad
!	If (ichoice.eq.1) rad_sw_in(i) = rad_sw_in1(i)
!	If (ichoice.eq.1) rad_lw_in(i) = rad_lw_in1(i)
!	If (ichoice.eq.2) rad_sw_in(i) = rad_sw_in2(i)
!	If (ichoice.eq.2) rad_lw_in(i) = rad_lw_in2(i)
!	Enddo

        Call check( nf90_open(FILE_NAME, nf90_write, ncid) )

	Call check( nf90_redef(ncid) )
  
	Call check( nf90_def_dim(ncid, TIME_RAD_NAME, itime_rad, time_rad_dimid) )

	Call check( nf90_def_var(ncid, TIME_RAD_NAME, NF90_REAL, time_rad_dimid, time_rad_varid) )
	Call check( nf90_def_var(ncid, RAD_SW_IN_NAME, NF90_REAL, time_rad_dimid, rad_sw_in_varid) )
	Call check( nf90_def_var(ncid, RAD_LW_IN_NAME, NF90_REAL, time_rad_dimid, rad_lw_in_varid) )

	Call check( nf90_put_att(ncid, time_rad_varid, UNITS, TIME_RAD_UNITS) )
	Call check( nf90_put_att(ncid, rad_sw_in_varid, UNITS, RAD_SW_IN_UNITS) )
	Call check( nf90_put_att(ncid, rad_lw_in_varid, UNITS, RAD_LW_IN_UNITS) )

	Call check( nf90_put_att(ncid, time_rad_varid, LNAME, TIME_RAD_LNAME) )
	Call check( nf90_put_att(ncid, rad_sw_in_varid, SNAME, RAD_SW_IN_SNAME) )
	Call check( nf90_put_att(ncid, rad_lw_in_varid, SNAME, RAD_LW_IN_SNAME) )

	Call check( nf90_put_att(ncid, rad_sw_in_varid, "_FillValue", fillval_rad_sw_in) )
	Call check( nf90_put_att(ncid, rad_lw_in_varid, "_FillValue", fillval_rad_lw_in) )

	Call check( nf90_put_att(ncid, rad_sw_in_varid, "lod", lod_rad) )
	Call check( nf90_put_att(ncid, rad_lw_in_varid, "lod", lod_rad) )

	Call check ( nf90_enddef(ncid) )

	Call check ( nf90_put_var(ncid, time_rad_varid, time_rad) )
	Call check ( nf90_put_var(ncid, rad_sw_in_varid, rad_sw_in) )
	Call check ( nf90_put_var(ncid, rad_lw_in_varid, rad_lw_in) )

	Call check ( nf90_close(ncid) )

	Print *, '05-Dec-2017 Dynamic Driver is updated with radiation data !'

contains
   	Subroutine check(status)
        integer, intent ( in) :: status
        if(status /= nf90_noerr) then
         print *, trim(nf90_strerror(status))
         stop "Stopped"
        end if
   	End subroutine check

	End program add_radiation_parameter 
